GoogleSearch_services.GoogleSearchBindingSOAP

|  | ## Cheshire3 Object Model: Class GoogleSearchBindingSOAP

Module GoogleSearch_services :: Class GoogleSearchBindingSOAP

## Class GoogleSearchBindingSOAP
source code

Instance Methods

__init__(self, addr, **kw)
doGetCachedPage(self, request)
doGoogleSearch(self, request)
doSpellingSuggestion(self, request)

Method Details

### __init__(self, addr, **kw) (Constructor) | source code

### doGetCachedPage(self, request) | source code
    Returns: response from doGetCachedPageResponse:
         _return: str

### doGoogleSearch(self, request) | source code
    Returns: response from doGoogleSearchResponse:
         _return: ns1.GoogleSearchResult_Def
           _directoryCategories: ns1.DirectoryCategoryArray_Def
             _element: ns1.DirectoryCategory_Def
               _fullViewableName: str
               _specialEncoding: str
           _documentFiltering: boolean
           _endIndex: int
           _estimateIsExact: boolean
           _estimatedTotalResultsCount: int
           _resultElements: ns1.ResultElementArray_Def
             _element: ns1.ResultElement_Def
               _URL: str
               _cachedSize: str
               _directoryCategory: ns1.DirectoryCategory_Def
               _directoryTitle: str
               _hostName: str
               _relatedInformationPresent: boolean
               _snippet: str
               _summary: str
               _title: str
           _searchComments: str
           _searchQuery: str
           _searchTime: float
           _searchTips: str
           _startIndex: int

### doSpellingSuggestion(self, request) | source code
    Returns: response from doSpellingSuggestionResponse:
         _return: str